netapp_ontap.models.dr_group_node API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.dr_group_node`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class DrGroupNodeSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the DrGroupNode object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `dr_ha_partners GET`

    The dr_ha_partners field of the dr_group_node.

  `dr_node GET POST`

    The dr_node field of the dr_group_node.

  `ha_partners GET`

    The ha_partners field of the dr_group_node.

  `ip_interfaces GET POST PATCH`

    The ip_interfaces field of the dr_group_node.

  `mirroring_enabled GET`

    The mirroring_enabled field of the dr_group_node.

  `node GET POST`

    The node field of the dr_group_node.

  `state GET`

    The state field of the dr_group_node.

    Valid choices:

    - normal
    - switchover_in_progress
    - switchover_failed
    - switchover_completed
    - heal_aggrs_in_progress
    - heal_aggrs_failed
    - heal_aggrs_completed
    - heal_roots_in_progress
    - heal_roots_failed
    - heal_roots_completed
    - switchback_in_progress
    - switchback_failed